@@ -10,7 +10,7 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: terminfo.ml,v 1.4 2002/01/14 15:50:18 filliatr Exp $ *)
+(* $Id: terminfo.ml,v 1.5 2004/08/23 09:43:25 filliatr Exp $ *)
 
 (* Basic interface to the terminfo database *)
 
@@ -19,7 +19,7 @@ type status =
   | Bad_term
   | Good_term of int
 ;;
-external setup : out_channel -> status = "terminfo_setup";;
-external backup : int -> unit = "terminfo_backup";;
-external standout : bool -> unit = "terminfo_standout";;
-external resume : int -> unit = "terminfo_resume";;
+external setup : out_channel -> status = "caml_terminfo_setup";;
+external backup : int -> unit = "caml_terminfo_backup";;
+external standout : bool -> unit = "caml_terminfo_standout";;
+external resume : int -> unit = "caml_terminfo_resume";;
