@@ -10,13 +10,13 @@
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: lex_syntax.mli,v 1.2 2000/12/03 17:40:05 marche Exp $ *)
+(* $Id: lex_syntax.mli,v 1.3 2004/10/12 12:29:19 filliatr Exp $ *)
 
 (* The shallow abstract syntax *)
 
 type location =
-    { start_pos: int;
-      end_pos: int;
+    { start_pos: Lexing.position;
+      end_pos: Lexing.position;
       start_line: int;
       start_col: int }
 
