@@ -14,7 +14,7 @@
  * (enclosed in the file LGPL).
  *)
 
-(*i $Id: output.ml,v 1.61 2003/01/31 16:51:46 filliatr Exp $ i*)
+(*i $Id: output.ml,v 1.64 2004/09/23 09:20:16 filliatr Exp $ i*)
 
 (*i*)
 open Printf
@@ -86,12 +86,19 @@ let (preamble : string Queue.t) = Queue.create ()
 
 let push_in_preamble s = Queue.add s preamble
 
+let class_options = ref "12pt"
+
+let fullpage_headings = ref true
+
 let latex_header opt =
   if not !no_preamble then begin
-    output_string "\\documentclass[12pt]{article}\n";
+    output_string (sprintf "\\documentclass[%s]{article}\n" !class_options);
     output_string "\\usepackage[latin1]{inputenc}\n";
-    output_string "\\usepackage[T1]{fontenc}\n";
-    output_string "\\usepackage{fullpage}\n";
+    (*i output_string "\\usepackage[T1]{fontenc}\n"; i*)
+    if !fullpage_headings then
+      output_string "\\usepackage[headings]{fullpage}\n"
+    else
+      output_string "\\usepackage{fullpage}\n";
     output_string "\\usepackage";
     if opt <> "" then output_string (sprintf "[%s]" opt);
     output_string "{ocamlweb}\n";
@@ -234,6 +241,8 @@ let output_escaped_char c =
 	output_char '\\'; output_char c
     | '^' | '~' -> 
 	output_char '\\'; output_char c; output_string "{}"
+    | '<' | '>' ->
+        output_string "\\ensuremath{"; output_char c; output_string "}"
     | _ -> 
 	output_char c
 
@@ -340,7 +349,7 @@ let output_symbol = function
   | "~-" -> enter_math (); output_string "-"
   | "[<" -> enter_math (); output_string "[\\langle{}"
   | ">]" -> enter_math (); output_string "\\rangle{}]"
-  | "(" | ")" | "[" | "]" | "[|" | "|]" as s -> 
+  | "<" | ">" | "(" | ")" | "[" | "]" | "[|" | "|]" as s -> 
             enter_math (); output_string s
   | "&" | "&&" ->
             enter_math (); output_string "\\land{}"
@@ -348,6 +357,7 @@ let output_symbol = function
             enter_math (); output_string "\\lor{}"
   | "not" -> enter_math (); output_string "\\lnot{}"
   | "[]" -> enter_math (); output_string "[\\,]"
+  | "|" -> enter_math (); output_string "\\mid{}"
   | s    -> output_latex_id s
 
 let use_greek_letters = ref true
@@ -425,7 +435,7 @@ let output_eyc () = leave_math (); output_string "\\ocweyc{}"
 
 (*s \textbf{Strings.} *)
 
-let output_bs () = leave_math (); output_string "\\texttt{\""
+let output_bs () = leave_math (); output_string "\\ocwstring{\""
 
 let output_es () = output_string "\"}"
 
