@@ -14,7 +14,7 @@
  * (enclosed in the file LGPL).
  *)
 
-(*i $Id: output.mli,v 1.35 2003/01/31 16:51:46 filliatr Exp $ i*)
+(*i $Id: output.mli,v 1.37 2004/09/23 09:20:16 filliatr Exp $ i*)
 
 (*s In that module, we concentrate all the printing functions.
    Thus, it will be easy to add another kind of output, HTML for instance,
@@ -53,8 +53,10 @@ val output_verbatim : string -> unit
     [latex_header] takes as argument the options of the \LaTeX\
     package ocamlweb.sty. *)
 
+val class_options : string ref
 val set_no_preamble : bool -> unit
 val push_in_preamble : string -> unit
+val fullpage_headings : bool ref
 val latex_header : string -> unit
 val latex_trailer : unit -> unit
 
